@@ -1,9 +1,10 @@
 from datetime import datetime
 from inspect import isclass
+import six
 import sqlalchemy as sa
 
 
-__version__ = '0.2.4'
+__version__ = '0.3.0'
 
 
 class Column(sa.Column):
@@ -113,10 +114,10 @@ class ModelConfigurator(object):
         Assigns int column server_default based on column default value
         """
         if column.default is not None:
-            if (isinstance(column.default.arg, basestring) or
-                    isinstance(column.default.arg, int)):
+            if (isinstance(column.default.arg, six.text_type) or
+                    isinstance(column.default.arg, six.integer_types)):
                 column.server_default = sa.schema.DefaultClause(
-                    str(column.default.arg)
+                    six.text_type(column.default.arg)
                 )
 
     def assign_string_defaults(self, column):
@@ -124,7 +125,7 @@ class ModelConfigurator(object):
         Assigns string column server_default based on column default value
         """
         if column.default is not None and (
-            isinstance(column.default.arg, basestring)
+            isinstance(column.default.arg, six.text_type)
         ):
             column.server_default = sa.schema.DefaultClause(
                 column.default.arg
